@@ -6,8 +6,6 @@ import os
 
 def environ_email():
     """Guess email from sudo user environment variable or login name."""
-    username = os.environ.get("SUDO_USER")
-    if not username:
-        username = getpass.getuser()
+    username = os.environ.get("SUDO_USER") or getpass.getuser()
 
     return f"{username}@scilifelab.se"
