@@ -2,7 +2,7 @@ import logging
 from glob import glob
 from pathlib import Path
 
-import click
+import rich_click as click
 from pydantic import ValidationError
 
 from cg.apps.demultiplex.demultiplex_api import DemultiplexingAPI
