@@ -2,10 +2,12 @@
 
 import logging
 
-import click
+import rich_click as click
 
+from cg.apps.scout.scoutapi import ScoutAPI
 from cg.constants import Workflow
 from cg.constants.constants import MAX_ITEMS_TO_RETRIEVE
+from cg.models.cg_config import CGConfig
 from cg.store.models import Analysis
 from cg.store.store import Store
 
@@ -20,3 +22,8 @@ def suggest_cases_to_upload(status_db: Store, workflow: Workflow | None = None)
     ]
     for case_obj in records:
         click.echo(case_obj)
+
+
+def get_scout_api(cg_config: CGConfig, case_id: str) -> ScoutAPI:
+    workflow = cg_config.status_db.get_case_by_internal_id(case_id).data_analysis
+    return cg_config.scout_api_38 if workflow == Workflow.NALLO else cg_config.scout_api_37
