@@ -8,6 +8,7 @@ import rich_click as click
 from cg.cli.utils import CLICK_CONTEXT_SETTINGS
 from cg.cli.workflow.commands import ARGUMENT_CASE_ID, resolve_compression
 from cg.cli.workflow.nf_analysis import (
+    OPTION_REVISION,
     metrics_deliver,
     report_deliver,
     store,
@@ -53,28 +54,30 @@ def config_case(cg_config: CGConfig, case_id: str):
 
 
 @rnafusion.command()
+@OPTION_REVISION
 @ARGUMENT_CASE_ID
 @click.pass_obj
-def run(cg_config: CGConfig, case_id: str):
+def run(cg_config: CGConfig, case_id: str, revision: str | None):
     """Run a preconfigured RNAFUSION case."""
     factory = AnalysisStarterFactory(cg_config)
     analysis_starter: AnalysisStarter = factory.get_analysis_starter_for_workflow(
         Workflow.RNAFUSION
     )
-    analysis_starter.run(case_id=case_id)
+    analysis_starter.run(case_id=case_id, revision=revision)
 
 
 @rnafusion.command()
+@OPTION_REVISION
 @ARGUMENT_CASE_ID
 @click.pass_obj
-def start(cg_config: CGConfig, case_id: str):
+def start(cg_config: CGConfig, case_id: str, revision: str | None):
     """Start an RNAFUSION case. Configures the case if needed."""
     LOG.info(f"Starting RNAFUSION workflow for case {case_id}.")
     factory = AnalysisStarterFactory(cg_config)
     analysis_starter: AnalysisStarter = factory.get_analysis_starter_for_workflow(
         Workflow.RNAFUSION
     )
-    analysis_starter.start(case_id=case_id)
+    analysis_starter.start(case_id=case_id, revision=revision)
 
 
 @rnafusion.command()
