@@ -9,49 +9,49 @@ GENOME_BUILD_38: str = "GRCh38"
 
 
 class GenePanelGenomeBuild(StrEnum):
-    hg19: str = GENOME_BUILD_37
-    hg38: str = GENOME_BUILD_38
+    hg19 = GENOME_BUILD_37
+    hg38 = GENOME_BUILD_38
 
 
 class GenePanelMasterList(StrEnum):
-    BRAIN: str = "BRAIN"
-    CARDIOLOGY: str = "Cardiology"
-    CILM: str = "CILM"
-    CH: str = "CH"
-    CHILDHYPOTONIA: str = "CHILDHYPOTONIA"
-    CTD: str = "CTD"
-    DIAB: str = "DIAB"
-    ENDO: str = "ENDO"
-    EP: str = "EP"
-    HEARING: str = "HEARING"
-    HYDRO: str = "HYDRO"
-    IBMFS: str = "IBMFS"
-    IEM: str = "IEM"
-    IF: str = "IF"
-    MCARTA: str = "mcarta"
-    MHT: str = "MHT"
-    MIT: str = "MIT"
-    MOVE: str = "MOVE"
-    MTDNA: str = "mtDNA"
-    NBS_M: str = "NBS-M"
-    NEURODEG: str = "NEURODEG"
-    NMD: str = "NMD"
-    OMIM_AUTO: str = "OMIM-AUTO"
-    OPTIC: str = "OPTIC"
-    PANELAPP_GREEN: str = "PANELAPP-GREEN"
-    PEDHEP: str = "PEDHEP"
-    PID: str = "PID"
-    PIDCAD: str = "PIDCAD"
-    RETINA: str = "RETINA"
-    SKD: str = "SKD"
-    SOVM: str = "SOVM"
-    STROKE: str = "STROKE"
-    AID: str = "AID"
-    INHERITED_CANCER: str = "Inherited cancer"
-    VEO_IBD: str = "VEO-IBD"
-    KIDNEY: str = "Kidney"
-    CAKUT: str = "CAKUT"
-    NCRNA: str = "ncRNA"
+    BRAIN = "BRAIN"
+    CARDIOLOGY = "Cardiology"
+    CILM = "CILM"
+    CH = "CH"
+    CHILDHYPOTONIA = "CHILDHYPOTONIA"
+    CTD = "CTD"
+    DIAB = "DIAB"
+    ENDO = "ENDO"
+    EP = "EP"
+    HEARING = "HEARING"
+    HYDRO = "HYDRO"
+    IBMFS = "IBMFS"
+    IEM = "IEM"
+    IF = "IF"
+    MCARTA = "mcarta"
+    MHT = "MHT"
+    MIT = "MIT"
+    MOVE = "MOVE"
+    MTDNA = "mtDNA"
+    NBS_M = "NBS-M"
+    NEURODEG = "NEURODEG"
+    NMD = "NMD"
+    OMIM_AUTO = "OMIM-AUTO"
+    OPTIC = "OPTIC"
+    PANELAPP_GREEN = "PANELAPP-GREEN"
+    PEDHEP = "PEDHEP"
+    PID = "PID"
+    PIDCAD = "PIDCAD"
+    RETINA = "RETINA"
+    SKD = "SKD"
+    SOVM = "SOVM"
+    STROKE = "STROKE"
+    AID = "AID"
+    INHERITED_CANCER = "Inherited cancer"
+    VEO_IBD = "VEO-IBD"
+    KIDNEY = "Kidney"
+    CAKUT = "CAKUT"
+    NCRNA = "ncRNA"
 
     @classmethod
     def get_panel_names(cls, panels=None) -> list[str]:
