@@ -113,6 +113,14 @@ MASTER_STEPS_UDFS = {
             "atlas_document": "Library Preparation Method",
             "atlas_version": "Atlas Version",
         },
+        "Library Prep PCR-free WGS v1": {
+            "atlas_document": "Library Preparation Method",
+            "atlas_version": "Atlas Version",
+        },
+        "SMRTbell library prep (Revio) v1": {
+            "atlas_document": "Library Preparation Method",
+            "atlas_version": "Atlas Version",
+        },
     },
     "sequencing_method_step": {
         "CG002 - Cluster Generation (HiSeq X)": {
@@ -133,6 +141,10 @@ MASTER_STEPS_UDFS = {
             "atlas_document": "Sequencing Method",
             "atlas_version": "Atlas Version",
         },
+        "Set Up Sequencing Run (Revio) v1": {
+            "atlas_document": "Sequencing Method",
+            "atlas_version": "Atlas Version",
+        },
     },
     "delivery_method_step": {
         "CG002 - Delivery": {
