@@ -12,9 +12,9 @@ class GenomeBuild(StrEnum):
 
 
 class ScoutExportFileName(StrEnum):
-    MANAGED_VARIANTS: str = f"managed_variants{FileExtensions.VCF}"
-    PANELS: str = f"gene_panels{FileExtensions.BED}"
-    PANELS_TSV: str = f"gene_panels{FileExtensions.TSV}"
+    MANAGED_VARIANTS = f"managed_variants{FileExtensions.VCF}"
+    PANELS = f"gene_panels{FileExtensions.BED}"
+    PANELS_TSV = f"gene_panels{FileExtensions.TSV}"
 
 
 class UploadTrack(StrEnum):
