@@ -23,6 +23,7 @@ from cg.meta.delivery.delivery import DeliveryAPI
 from cg.meta.delivery_report.data_validators import get_empty_report_data, get_missing_report_data
 from cg.meta.workflow.analysis import AnalysisAPI
 from cg.models.analysis import AnalysisModel
+from cg.models.delivery.delivery import DeliveryFile
 from cg.models.delivery_report.metadata import SampleMetadataModel
 from cg.models.delivery_report.report import (
     CaseModel,
@@ -250,14 +251,14 @@ class DeliveryReportAPI:
         for case_sample in case_samples:
             sample: Sample = case_sample.sample
             lims_sample: dict[str, Any] = self.lims_api.sample(sample.internal_id)
-            delivered_files: list[File] | None = (
+            delivered_files: list[DeliveryFile] | None = (
                 self.delivery_api.get_analysis_sample_delivery_files_by_sample(
                     case=case, sample=sample
                 )
                 if self.delivery_api.is_analysis_delivery(case.data_delivery)
                 else None
             )
-            delivered_fastq_files: list[File] | None = (
+            delivered_fastq_files: list[DeliveryFile] | None = (
                 self.delivery_api.get_fastq_delivery_files_by_sample(case=case, sample=sample)
                 if self.delivery_api.is_fastq_delivery(case.data_delivery)
                 else None
@@ -332,7 +333,7 @@ class DeliveryReportAPI:
 
     def get_case_analysis_data(self, case: Case, analysis: Analysis) -> DataAnalysisModel:
         """Return workflow attributes used for data analysis."""
-        delivered_files: list[File] | None = (
+        delivered_files: list[DeliveryFile] | None = (
             self.delivery_api.get_analysis_case_delivery_files(case)
             if self.delivery_api.is_analysis_delivery(case.data_delivery)
             else None
