@@ -5,7 +5,6 @@ import logging
 
 import rich_click as click
 
-from cg.apps.gens import GensAPI
 from cg.cli.generate.delivery_report.base import generate_delivery_report
 from cg.cli.upload.genotype import upload_genotypes
 from cg.cli.upload.gens import upload_to_gens
@@ -59,13 +58,7 @@ class BalsamicUploadAPI(UploadAPI):
             LOG.info(f"Balsamic case {case.internal_id} is not compatible for Genotype upload")
 
         # Observations upload
-        if (
-            self.analysis_api.get_case_application_type(case_id=case.internal_id)
-            == SeqLibraryPrepCategory.WHOLE_GENOME_SEQUENCING
-        ):
-            ctx.invoke(upload_observations_to_loqusdb, case_id=case.internal_id)
-        else:
-            LOG.info(f"Balsamic case {case.internal_id} is not compatible for Observations upload")
+        ctx.invoke(upload_observations_to_loqusdb, case_id=case.internal_id)
         LOG.info(
             f"Upload of case {case.internal_id} was successful. Setting uploaded at to {dt.datetime.now()}"
         )
