@@ -3,10 +3,9 @@
 import datetime as dt
 import logging
 
-import click
-
-from cg.cli.generate.report.base import generate_delivery_report
+import rich_click as click
 
+from cg.cli.generate.delivery_report.base import generate_delivery_report
 from cg.cli.upload.scout import upload_to_scout
 from cg.constants import (
     REPORT_SUPPORTED_DATA_DELIVERY,
@@ -31,7 +30,7 @@ class NfAnalysisUploadAPI(UploadAPI):
 
     def upload(self, ctx: click.Context, case: Case, restart: bool) -> None:
         """Upload NF analysis data and files."""
-        analysis: Analysis = case.analyses[0]
+        analysis: Analysis = self.status_db.get_latest_completed_analysis_for_case(case.internal_id)
         self.update_upload_started_at(analysis=analysis)
 
         # Delivery report generation
