@@ -28,6 +28,13 @@ class BalsamicObservationsInputFiles(ObservationsInputFiles):
     sv_germline_vcf_path: FilePath | None = None
 
 
+class NalloObservationsInputFiles(ObservationsInputFiles):
+    """Model for validating Nallo Loqusdb input files."""
+
+    profile_vcf_path: FilePath
+    family_ped_path: FilePath
+
+
 class RarediseaseObservationsInputFiles(ObservationsInputFiles):
     """Model for validating RAREDISEASE Loqusdb input files."""
 
