@@ -892,16 +892,26 @@ class PacbioSmrtCellView(BaseView):
 
 
 class PacbioSampleRunMetricsView(BaseView):
+    column_filters = ["instrument_run.run_name", "instrument_run.plate"]
+    column_formatters = {
+        "smrt_cell": PacbioSmrtCellView.view_smrt_cell_link,
+        "sample": SampleView.view_sample_link,
+    }
+    column_labels = {
+        "instrument_run.run_name": "Run name",
+        "instrument_run.plate": "Plate",
+    }
     column_list = [
         "smrt_cell",
         "sample",
+        "instrument_run.run_name",
+        "instrument_run.plate",
         "hifi_reads",
         "hifi_yield",
         "hifi_mean_read_length",
         "hifi_median_read_quality",
     ]
-    column_formatters = {
-        "smrt_cell": PacbioSmrtCellView.view_smrt_cell_link,
-        "sample": SampleView.view_sample_link,
-    }
-    column_searchable_list = ["sample.internal_id", "instrument_run.device.internal_id"]
+    column_searchable_list = [
+        "sample.internal_id",
+        "instrument_run.device.internal_id",
+    ]
