@@ -1,5 +1,6 @@
 from abc import ABC, abstractmethod
 from pathlib import Path
+from typing import Any
 
 
 class ParamsFileCreator(ABC):
@@ -8,5 +9,5 @@ class ParamsFileCreator(ABC):
         self.params = Path(params)
 
     @abstractmethod
-    def create(self, case_id: str, file_path: Path, sample_sheet_path: Path) -> any:
+    def create(self, case_id: str, file_path: Path, sample_sheet_path: Path) -> Any:
         pass
