@@ -1,25 +1,35 @@
-from cg.services.delivery_message.messages.analysis_scout_message import (
-    AnalysisScoutMessage,
-)
+from cg.services.delivery_message.messages.analysis_scout_message import AnalysisScoutMessage
 from cg.services.delivery_message.messages.covid_message import CovidMessage
 from cg.services.delivery_message.messages.fastq_analysis_scout_message import (
     FastqAnalysisScoutMessage,
 )
 from cg.services.delivery_message.messages.fastq_message import FastqMessage
 from cg.services.delivery_message.messages.fastq_scout_message import FastqScoutMessage
-from cg.services.delivery_message.messages.microsalt_mwr_message import (
-    MicrosaltMwrMessage,
-)
-from cg.services.delivery_message.messages.microsalt_mwx_message import (
-    MicrosaltMwxMessage,
+from cg.services.delivery_message.messages.microsalt_message import MicrosaltMessage
+from cg.services.delivery_message.messages.rna_delivery_message import (
+    RNAAnalysisStrategy,
+    RNADeliveryMessage,
+    RNAFastqAnalysisStrategy,
+    RNAFastqStrategy,
+    RNAScoutStrategy,
+    RNAUploadMessageStrategy,
 )
 from cg.services.delivery_message.messages.scout_message import ScoutMessage
 from cg.services.delivery_message.messages.statina_message import StatinaMessage
-from cg.services.delivery_message.messages.rna_delivery_message import (
-    RNAScoutStrategy,
-    RNAFastqStrategy,
-    RNAAnalysisStrategy,
-    RNAFastqAnalysisStrategy,
-    RNAUploadMessageStrategy,
-    RNADeliveryMessage,
-)
+
+__all__ = [
+    "AnalysisScoutMessage",
+    "CovidMessage",
+    "FastqAnalysisScoutMessage",
+    "FastqMessage",
+    "FastqScoutMessage",
+    "MicrosaltMessage",
+    "RNAAnalysisStrategy",
+    "RNADeliveryMessage",
+    "RNAFastqAnalysisStrategy",
+    "RNAFastqStrategy",
+    "RNAScoutStrategy",
+    "RNAUploadMessageStrategy",
+    "ScoutMessage",
+    "StatinaMessage",
+]
