@@ -1,5 +1,8 @@
 from cg.services.delivery_message.messages.delivery_message import DeliveryMessage
-from cg.services.delivery_message.messages.utils import get_caesar_delivery_path
+from cg.services.delivery_message.messages.utils import (
+    REMINDER_TO_DOWNLOAD_MESSAGE,
+    get_caesar_delivery_path,
+)
 from cg.store.models import Case
 
 
@@ -12,7 +15,8 @@ def get_cases_message(cases: list[Case]) -> str:
         f"The analysis files for the following {case_s_} are currently being uploaded to your inbox on Caesar:\n\n"
         f"{case_names}\n\n"
         f"Available under: \n\n"
-        f"{delivery_path}"
+        f"{delivery_path} \n\n"
+        f"{REMINDER_TO_DOWNLOAD_MESSAGE}"
     )
 
 
